contextMenu.js
==============
<p>contextMenu.js is a   plugin to create windows like context menu with keyboard interaction, different  type of inputs ,trigger events and much more.<br />
  Why contextMenu.js ?:</p>
<ul>
  <li>Use as simple popup or as a context menu. With some tweaking, it can be used for multiple purposes.</li>
  <li>Adjust position and size to fit in viewport.</li>
  <li>Keyboard interaction.</li>
  <li>Support for different types of inputs (structure object, UL list)  .</li>
  <li>Trigger Context menu with right-click, left-click,hover or any other mouse events.</li>
  <li>Support touch devices.</li>
  <li>Css outside of javascript so you can edit the  look of menu.</li>
  <li>Enable/disable options.</li>
  <li>Optional icons for commands.</li>
  <li>Lot of configurable options.</li>
  <li>Submenus</li>
</ul>
<strong>See demo and documentation on http://ignitersworld.com/lab/contextMenu.html</strong>

<h3>Major Updates</h3>

<h4>1.4.0</h4>
<ol>
    <li> Added support for touch devices. (Make sure to update css file too) </li>
    <li> Removed sizeStyle option and forced menu to take height of inner content. With size style auto lot of issue with different devices were coming. </li>
</ol>

<h4>1.2.0</h4>
<ol>
  <li>Added a "closeOnClick" option to close contentext menu on click of any item.</li>
  <li>Added a className key when generating context menu through object to give style on specific item of menu.</li>
  <li>Fixed keybord event.</li>
</ol>